Properties Methods Events Config Options Direct Link

# Class Ext.ux.ValidationStatus

Package: | Ext.ux
Defined In: | ValidationStatus.js
Class: | ValidationStatus
Extends: | Object

A Ext.StatusBar plugin that provides automatic error notification when the associated form contains validation errors.

## Config Options

Config Options | Defined By
--- | ---
| errorIconCls : String The iconCls value to be applied to the status message when there is a validation error. Defaults to `'x-status-error'`. | ValidationStatus
| errorIconCls : String The iconCls value to be applied to the status message when there is a validation error. Defaults to `'x-status-error'`. | ValidationStatus
| errorListCls : String The css class to be used for the error list when there are validation errors. Defaults to `'x-status-error-list'`. | ValidationStatus
| errorListCls : String The css class to be used for the error list when there are validation errors. Defaults to `'x-status-error-list'`. | ValidationStatus
| showText : String The text value to be applied when there is a form validation error. Defaults to 'The form has errors (click for detai... The text value to be applied when there is a form validation error. Defaults to `'The form has errors (click for details...)'`. | ValidationStatus
| showText : String The text value to display when the error list is displayed. Defaults to `'Click again to hide the error list'`. | ValidationStatus
| showText : String The text value to be applied when there is a form validation error. Defaults to 'The form has errors (click for detai... The text value to be applied when there is a form validation error. Defaults to `'The form has errors (click for details...)'`. | ValidationStatus
| showText : String The text value to display when the error list is displayed. Defaults to `'Click again to hide the error list'`. | ValidationStatus
| submitText : String The text value to be applied when the form is being submitted. Defaults to `'Saving...'`. | ValidationStatus
| submitText : String The text value to be applied when the form is being submitted. Defaults to `'Saving...'`. | ValidationStatus
| validIconCls : String The iconCls value to be applied to the status message when the form validates. Defaults to `'x-status-valid'`. | ValidationStatus
| validIconCls : String The iconCls value to be applied to the status message when the form validates. Defaults to `'x-status-valid'`. | ValidationStatus

## Public Properties

This class has no public properties.

## Public Methods

This class has no public methods.

## Public Events

This class has no public events.